"use strict";
// Copyright (c) Jupyter Development Team.
// Copyright (c) Microsoft Corporation.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.breadcrumbItemStyles = void 0;
const fast_element_1 = require("@microsoft/fast-element");
const fast_foundation_1 = require("@microsoft/fast-foundation");
const fast_web_utilities_1 = require("@microsoft/fast-web-utilities");
const fast_components_1 = require("@microsoft/fast-components");
const index_1 = require("../styles/index");
/**
 * Styles for Breadcrumb item
 * @public
 */
const breadcrumbItemStyles = (context, definition) => fast_element_1.css `
    ${fast_foundation_1.display('inline-flex')} :host {
        background: transparent;
        box-sizing: border-box;
        font-family: ${fast_components_1.bodyFont};
        font-size: ${fast_components_1.typeRampBaseFontSize};
        fill: currentColor;
        line-height: ${fast_components_1.typeRampBaseLineHeight};
        min-width: calc(${index_1.heightNumber} * 1px);
        outline: none;
        color: ${fast_components_1.neutralForegroundRest}
    }

    .listitem {
        display: flex;
        align-items: center;
        width: max-content;
    }

    .separator {
        margin: 0 6px;
        display: flex;
    }

    .control {
        align-items: center;
        box-sizing: border-box;
        color: ${fast_components_1.accentForegroundRest};
        cursor: pointer;
        display: flex;
        fill: inherit;
        outline: none;
        text-decoration: none;
        white-space: nowrap;
    }

    .control:hover {
        color: ${fast_components_1.accentForegroundHover};
    }

    .control:active {
        color: ${fast_components_1.accentForegroundActive};
    }

    .control .content {
        position: relative;
    }

    .control .content::before {
        content: "";
        display: block;
        height: calc(${fast_components_1.strokeWidth} * 1px);
        left: 0;
        position: absolute;
        right: 0;
        top: calc(1em + 4px);
        width: 100%;
    }

    .control:hover .content::before {
        background: ${fast_components_1.accentForegroundHover};
    }

    .control:active .content::before {
        background: ${fast_components_1.accentForegroundActive};
    }

    .control:${fast_foundation_1.focusVisible} .content::before {
        background: ${fast_components_1.accentForegroundFocus};
        height: calc(${fast_components_1.focusStrokeWidth} * 1px);
    }

    .control:not([href]) {
        color: ${fast_components_1.neutralForegroundRest};
        cursor: default;
    }

    .control:not([href]) .content::before {
        background: none;
    }

    .start,
    .end {
        display: flex;
    }

    ::slotted(svg) {
        /* TODO: adaptive typography https://github.com/microsoft/fast/issues/2432 */
        width: 16px;
        height: 16px;
    }

    .start {
        margin-inline-end: 6px;
    }

    .end {
        margin-inline-start: 6px;
    }
`.withBehaviors(fast_foundation_1.forcedColorsStylesheetBehavior(fast_element_1.css `
        .control:hover .content::before,
                .control:${fast_foundation_1.focusVisible} .content::before {
          background: ${fast_web_utilities_1.SystemColors.LinkText};
        }
        .start,
        .end {
          fill: ${fast_web_utilities_1.SystemColors.ButtonText};
        }
      `));
exports.breadcrumbItemStyles = breadcrumbItemStyles;
//# sourceMappingURL=breadcrumb-item.styles.js.map