"use strict";
// Copyright (c) Jupyter Development Team.
// Copyright (c) Microsoft Corporation.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.buttonStyles = exports.LightweightButtonStyles = void 0;
const fast_components_1 = require("@microsoft/fast-components");
const fast_element_1 = require("@microsoft/fast-element");
const fast_foundation_1 = require("@microsoft/fast-foundation");
const fast_web_utilities_1 = require("@microsoft/fast-web-utilities");
const design_token_1 = require("../design-token");
const styles_1 = require("../styles");
/**
 * Behavior that will conditionally apply a stylesheet based on the elements
 * appearance property
 *
 * @param value - The value of the appearance property
 * @param styles - The styles to be applied when condition matches
 *
 * @internal
 */
function appearanceBehavior(value, styles) {
    return new fast_foundation_1.PropertyStyleSheetBehavior('appearance', value, styles);
}
// TODO do we really want to use outline for focus => this call for a minimal style for toolbar probably
// outline force to use a margin so that the outline is not hidden by other elements.
/**
 * @internal
 */
const BaseButtonStyles = fast_element_1.css `
  ${fast_foundation_1.display('inline-flex')} :host {
    font-family: ${fast_components_1.bodyFont};
    outline: none;
    font-size: ${fast_components_1.typeRampBaseFontSize};
    line-height: ${fast_components_1.typeRampBaseLineHeight};
    height: calc(${styles_1.heightNumber} * 1px);
    min-width: calc(${styles_1.heightNumber} * 1px);
    background-color: ${fast_components_1.neutralFillRest};
    color: ${fast_components_1.neutralForegroundRest};
    border-radius: calc(${fast_components_1.controlCornerRadius} * 1px);
    fill: currentcolor;
    cursor: pointer;
    margin: calc((${fast_components_1.focusStrokeWidth} + 2) * 1px);
  }

  .control {
    background: transparent;
    height: inherit;
    flex-grow: 1;
    box-sizing: border-box;
    display: inline-flex;
    justify-content: center;
    align-items: center;
    padding: 0 calc((10 + (${fast_components_1.designUnit} * 2 * ${fast_components_1.density})) * 1px);
    white-space: nowrap;
    outline: none;
    text-decoration: none;
    border: calc(${fast_components_1.strokeWidth} * 1px) solid transparent;
    color: inherit;
    border-radius: inherit;
    fill: inherit;
    cursor: inherit;
    font-family: inherit;
    font-size: inherit;
    line-height: inherit;
  }

  :host(:hover) {
    background-color: ${fast_components_1.neutralFillHover};
  }

  :host(:active) {
    background-color: ${fast_components_1.neutralFillActive};
  }

  :host([minimal]) {
    --density: -4;
  }

  :host([minimal]) .control {
    padding: 1px;
  }

  /* prettier-ignore */
  .control:${fast_foundation_1.focusVisible} {
    outline: calc(${fast_components_1.focusStrokeWidth} * 1px) solid ${fast_components_1.neutralFillStrongFocus};
    outline-offset: 2px;
    -moz-outline-radius: 0px;
  }

  .control::-moz-focus-inner {
    border: 0;
  }

  .start,
  .end {
    display: flex;
  }

  .control.icon-only {
    padding: 0;
    line-height: 0;
  }

  ::slotted(svg) {
    ${
/* Glyph size and margin-left is temporary -
   replace when adaptive typography is figured out */ ''} width: 16px;
    height: 16px;
    pointer-events: none;
  }

  .start {
    margin-inline-end: 11px;
  }

  .end {
    margin-inline-start: 11px;
  }
`.withBehaviors(fast_foundation_1.forcedColorsStylesheetBehavior(fast_element_1.css `
      :host .control {
        background-color: ${fast_web_utilities_1.SystemColors.ButtonFace};
        border-color: ${fast_web_utilities_1.SystemColors.ButtonText};
        color: ${fast_web_utilities_1.SystemColors.ButtonText};
        fill: currentColor;
      }

      :host(:hover) .control {
        forced-color-adjust: none;
        background-color: ${fast_web_utilities_1.SystemColors.Highlight};
        color: ${fast_web_utilities_1.SystemColors.HighlightText};
      }

      /* prettier-ignore */
      .control:${fast_foundation_1.focusVisible} {
        forced-color-adjust: none;
        background-color: ${fast_web_utilities_1.SystemColors.Highlight};
        outline-color: ${fast_web_utilities_1.SystemColors.ButtonText};
        color: ${fast_web_utilities_1.SystemColors.HighlightText};
      }

      .control:hover,
      :host([appearance='outline']) .control:hover {
        border-color: ${fast_web_utilities_1.SystemColors.ButtonText};
      }

      :host([href]) .control {
        border-color: ${fast_web_utilities_1.SystemColors.LinkText};
        color: ${fast_web_utilities_1.SystemColors.LinkText};
      }

      :host([href]) .control:hover,
      :host([href]) .control:${fast_foundation_1.focusVisible} {
        forced-color-adjust: none;
        background: ${fast_web_utilities_1.SystemColors.ButtonFace};
        outline-color: ${fast_web_utilities_1.SystemColors.LinkText};
        color: ${fast_web_utilities_1.SystemColors.LinkText};
        fill: currentColor;
      }
    `));
/**
 * @internal
 */
const AccentButtonStyles = fast_element_1.css `
  :host([appearance='accent']) {
    background: ${fast_components_1.accentFillRest};
    color: ${fast_components_1.foregroundOnAccentRest};
  }

  :host([appearance='accent']:hover) {
    background: ${fast_components_1.accentFillHover};
    color: ${fast_components_1.foregroundOnAccentHover};
  }

  :host([appearance='accent']:active) .control:active {
    background: ${fast_components_1.accentFillActive};
    color: ${fast_components_1.foregroundOnAccentActive};
  }

  :host([appearance="accent"]) .control:${fast_foundation_1.focusVisible} {
    outline-color: ${fast_components_1.accentFillFocus};
  }
`.withBehaviors(fast_foundation_1.forcedColorsStylesheetBehavior(fast_element_1.css `
      :host([appearance='accent']) .control {
        forced-color-adjust: none;
        background: ${fast_web_utilities_1.SystemColors.Highlight};
        color: ${fast_web_utilities_1.SystemColors.HighlightText};
      }

      :host([appearance='accent']) .control:hover,
      :host([appearance='accent']:active) .control:active {
        background: ${fast_web_utilities_1.SystemColors.HighlightText};
        border-color: ${fast_web_utilities_1.SystemColors.Highlight};
        color: ${fast_web_utilities_1.SystemColors.Highlight};
      }

      :host([appearance="accent"]) .control:${fast_foundation_1.focusVisible} {
        outline-color: ${fast_web_utilities_1.SystemColors.Highlight};
      }

      :host([appearance='accent'][href]) .control {
        background: ${fast_web_utilities_1.SystemColors.LinkText};
        color: ${fast_web_utilities_1.SystemColors.HighlightText};
      }

      :host([appearance='accent'][href]) .control:hover {
        background: ${fast_web_utilities_1.SystemColors.ButtonFace};
        border-color: ${fast_web_utilities_1.SystemColors.LinkText};
        box-shadow: none;
        color: ${fast_web_utilities_1.SystemColors.LinkText};
        fill: currentColor;
      }

      :host([appearance="accent"][href]) .control:${fast_foundation_1.focusVisible} {
        outline-color: ${fast_web_utilities_1.SystemColors.HighlightText};
      }
    `));
/**
 * @internal
 */
const ErrorButtonStyles = fast_element_1.css `
  :host([appearance='error']) {
    background: ${design_token_1.errorFillRest};
    color: ${fast_components_1.foregroundOnAccentRest};
  }

  :host([appearance='error']:hover) {
    background: ${design_token_1.errorFillHover};
    color: ${fast_components_1.foregroundOnAccentHover};
  }

  :host([appearance='error']:active) .control:active {
    background: ${design_token_1.errorFillActive};
    color: ${fast_components_1.foregroundOnAccentActive};
  }

  :host([appearance="error"]) .control:${fast_foundation_1.focusVisible} {
    outline-color: ${design_token_1.errorFillFocus};
  }
`.withBehaviors(fast_foundation_1.forcedColorsStylesheetBehavior(fast_element_1.css `
      :host([appearance='error']) .control {
        forced-color-adjust: none;
        background: ${fast_web_utilities_1.SystemColors.Highlight};
        color: ${fast_web_utilities_1.SystemColors.HighlightText};
      }

      :host([appearance='error']) .control:hover,
      :host([appearance='error']:active) .control:active {
        background: ${fast_web_utilities_1.SystemColors.HighlightText};
        border-color: ${fast_web_utilities_1.SystemColors.Highlight};
        color: ${fast_web_utilities_1.SystemColors.Highlight};
      }

      :host([appearance="error"]) .control:${fast_foundation_1.focusVisible} {
        outline-color: ${fast_web_utilities_1.SystemColors.Highlight};
      }

      :host([appearance='error'][href]) .control {
        background: ${fast_web_utilities_1.SystemColors.LinkText};
        color: ${fast_web_utilities_1.SystemColors.HighlightText};
      }

      :host([appearance='error'][href]) .control:hover {
        background: ${fast_web_utilities_1.SystemColors.ButtonFace};
        border-color: ${fast_web_utilities_1.SystemColors.LinkText};
        box-shadow: none;
        color: ${fast_web_utilities_1.SystemColors.LinkText};
        fill: currentColor;
      }

      :host([appearance="error"][href]) .control:${fast_foundation_1.focusVisible} {
        outline-color: ${fast_web_utilities_1.SystemColors.HighlightText};
      }
    `));
/**
 * @internal
 */
exports.LightweightButtonStyles = fast_element_1.css `
  :host([appearance='lightweight']) {
    background: transparent;
    color: ${fast_components_1.accentForegroundRest};
  }

  :host([appearance='lightweight']) .control {
    padding: 0;
    height: initial;
    border: none;
    box-shadow: none;
    border-radius: 0;
  }

  :host([appearance='lightweight']:hover) {
    background: transparent;
    color: ${fast_components_1.accentForegroundHover};
  }

  :host([appearance='lightweight']:active) {
    background: transparent;
    color: ${fast_components_1.accentForegroundActive};
  }

  :host([appearance='lightweight']) .content {
    position: relative;
  }

  :host([appearance='lightweight']) .content::before {
    content: '';
    display: block;
    height: calc(${fast_components_1.strokeWidth} * 1px);
    position: absolute;
    top: calc(1em + 4px);
    width: 100%;
  }

  :host([appearance='lightweight']:hover) .content::before {
    background: ${fast_components_1.accentForegroundHover};
  }

  :host([appearance='lightweight']:active) .content::before {
    background: ${fast_components_1.accentForegroundActive};
  }

  :host([appearance="lightweight"]) .control:${fast_foundation_1.focusVisible} {
    outline-color: transparent;
  }

  :host([appearance="lightweight"]) .control:${fast_foundation_1.focusVisible} .content::before {
    background: ${fast_components_1.neutralForegroundRest};
    height: calc(${fast_components_1.focusStrokeWidth} * 1px);
  }
`.withBehaviors(fast_foundation_1.forcedColorsStylesheetBehavior(fast_element_1.css `
      :host([appearance="lightweight"]) .control:hover,
      :host([appearance="lightweight"]) .control:${fast_foundation_1.focusVisible} {
        forced-color-adjust: none;
        background: ${fast_web_utilities_1.SystemColors.ButtonFace};
        color: ${fast_web_utilities_1.SystemColors.Highlight};
      }
      :host([appearance="lightweight"]) .control:hover .content::before,
      :host([appearance="lightweight"]) .control:${fast_foundation_1.focusVisible} .content::before {
        background: ${fast_web_utilities_1.SystemColors.Highlight};
      }

      :host([appearance="lightweight"][href]) .control:hover,
      :host([appearance="lightweight"][href]) .control:${fast_foundation_1.focusVisible} {
        background: ${fast_web_utilities_1.SystemColors.ButtonFace};
        box-shadow: none;
        color: ${fast_web_utilities_1.SystemColors.LinkText};
      }

      :host([appearance="lightweight"][href]) .control:hover .content::before,
      :host([appearance="lightweight"][href]) .control:${fast_foundation_1.focusVisible} .content::before {
        background: ${fast_web_utilities_1.SystemColors.LinkText};
      }
    `));
/**
 * @internal
 */
const OutlineButtonStyles = fast_element_1.css `
  :host([appearance='outline']) {
    background: transparent;
    border-color: ${fast_components_1.accentFillRest};
  }

  :host([appearance='outline']:hover) {
    border-color: ${fast_components_1.accentFillHover};
  }

  :host([appearance='outline']:active) {
    border-color: ${fast_components_1.accentFillActive};
  }

  :host([appearance='outline']) .control {
    border-color: inherit;
  }

  :host([appearance="outline"]) .control:${fast_foundation_1.focusVisible} {
    outline-color: ${fast_components_1.accentFillFocus};
  }
`.withBehaviors(fast_foundation_1.forcedColorsStylesheetBehavior(fast_element_1.css `
      :host([appearance='outline']) .control {
        border-color: ${fast_web_utilities_1.SystemColors.ButtonText};
      }
      :host([appearance="outline"]) .control:${fast_foundation_1.focusVisible} {
        forced-color-adjust: none;
        background-color: ${fast_web_utilities_1.SystemColors.Highlight};
        outline-color: ${fast_web_utilities_1.SystemColors.ButtonText};
        color: ${fast_web_utilities_1.SystemColors.HighlightText};
        fill: currentColor;
      }
      :host([appearance='outline'][href]) .control {
        background: ${fast_web_utilities_1.SystemColors.ButtonFace};
        border-color: ${fast_web_utilities_1.SystemColors.LinkText};
        color: ${fast_web_utilities_1.SystemColors.LinkText};
        fill: currentColor;
      }
      :host([appearance="outline"][href]) .control:hover,
      :host([appearance="outline"][href]) .control:${fast_foundation_1.focusVisible} {
        forced-color-adjust: none;
        outline-color: ${fast_web_utilities_1.SystemColors.LinkText};
      }
    `));
/**
 * @internal
 */
const StealthButtonStyles = fast_element_1.css `
  :host([appearance='stealth']) {
    background: transparent;
  }

  :host([appearance='stealth']:hover) {
    background: ${fast_components_1.neutralFillStealthHover};
  }

  :host([appearance='stealth']:active) {
    background: ${fast_components_1.neutralFillStealthActive};
  }

  :host([appearance='stealth']) .control:${fast_foundation_1.focusVisible} {
    outline-color: ${fast_components_1.accentFillFocus};
  }
`.withBehaviors(fast_foundation_1.forcedColorsStylesheetBehavior(fast_element_1.css `
      :host([appearance='stealth']),
      :host([appearance='stealth']) .control {
        forced-color-adjust: none;
        background: ${fast_web_utilities_1.SystemColors.ButtonFace};
        border-color: transparent;
        color: ${fast_web_utilities_1.SystemColors.ButtonText};
        fill: currentColor;
      }

      :host([appearance='stealth']:hover) .control {
        background: ${fast_web_utilities_1.SystemColors.Highlight};
        border-color: ${fast_web_utilities_1.SystemColors.Highlight};
        color: ${fast_web_utilities_1.SystemColors.HighlightText};
        fill: currentColor;
      }

      :host([appearance="stealth"]:${fast_foundation_1.focusVisible}) .control {
        outline-color: ${fast_web_utilities_1.SystemColors.Highlight};
        color: ${fast_web_utilities_1.SystemColors.HighlightText};
        fill: currentColor;
      }

      :host([appearance='stealth'][href]) .control {
        color: ${fast_web_utilities_1.SystemColors.LinkText};
      }

      :host([appearance="stealth"][href]:hover) .control,
      :host([appearance="stealth"][href]:${fast_foundation_1.focusVisible}) .control {
        background: ${fast_web_utilities_1.SystemColors.LinkText};
        border-color: ${fast_web_utilities_1.SystemColors.LinkText};
        color: ${fast_web_utilities_1.SystemColors.HighlightText};
        fill: currentColor;
      }

      :host([appearance="stealth"][href]:${fast_foundation_1.focusVisible}) .control {
        forced-color-adjust: none;
        box-shadow: 0 0 0 1px ${fast_web_utilities_1.SystemColors.LinkText};
      }
    `));
/**
 * Styles for Button
 * @public
 */
const buttonStyles = (context, definition) => fast_element_1.css `
    :host([disabled]),
    :host([disabled]:hover),
    :host([disabled]:active) {
      opacity: ${fast_components_1.disabledOpacity};
      background-color: ${fast_components_1.neutralFillRest};
      cursor: ${fast_foundation_1.disabledCursor};
    }

    ${BaseButtonStyles}
  `.withBehaviors(fast_foundation_1.forcedColorsStylesheetBehavior(fast_element_1.css `
        :host([disabled]),
        :host([disabled]) .control,
        :host([disabled]:hover),
        :host([disabled]:active) {
          forced-color-adjust: none;
          background-color: ${fast_web_utilities_1.SystemColors.ButtonFace};
          outline-color: ${fast_web_utilities_1.SystemColors.GrayText};
          color: ${fast_web_utilities_1.SystemColors.GrayText};
          cursor: ${fast_foundation_1.disabledCursor};
          opacity: 1;
        }
      `), appearanceBehavior('accent', fast_element_1.css `
        :host([appearance='accent'][disabled]),
        :host([appearance='accent'][disabled]:hover),
        :host([appearance='accent'][disabled]:active) {
          background: ${fast_components_1.accentFillRest};
        }

        ${AccentButtonStyles}
      `.withBehaviors(fast_foundation_1.forcedColorsStylesheetBehavior(fast_element_1.css `
            :host([appearance='accent'][disabled]) .control,
            :host([appearance='accent'][disabled]) .control:hover {
              background: ${fast_web_utilities_1.SystemColors.ButtonFace};
              border-color: ${fast_web_utilities_1.SystemColors.GrayText};
              color: ${fast_web_utilities_1.SystemColors.GrayText};
            }
          `))), appearanceBehavior('error', fast_element_1.css `
        :host([appearance='error'][disabled]),
        :host([appearance='error'][disabled]:hover),
        :host([appearance='error'][disabled]:active) {
          background: ${design_token_1.errorFillRest};
        }

        ${ErrorButtonStyles}
      `.withBehaviors(fast_foundation_1.forcedColorsStylesheetBehavior(fast_element_1.css `
            :host([appearance='error'][disabled]) .control,
            :host([appearance='error'][disabled]) .control:hover {
              background: ${fast_web_utilities_1.SystemColors.ButtonFace};
              border-color: ${fast_web_utilities_1.SystemColors.GrayText};
              color: ${fast_web_utilities_1.SystemColors.GrayText};
            }
          `))), appearanceBehavior('lightweight', fast_element_1.css `
        :host([appearance='lightweight'][disabled]:hover),
        :host([appearance='lightweight'][disabled]:active) {
          background-color: transparent;
          color: ${fast_components_1.accentForegroundRest};
        }

        :host([appearance='lightweight'][disabled]) .content::before,
        :host([appearance='lightweight'][disabled]:hover) .content::before,
        :host([appearance='lightweight'][disabled]:active) .content::before {
          background: transparent;
        }

        ${exports.LightweightButtonStyles}
      `.withBehaviors(fast_foundation_1.forcedColorsStylesheetBehavior(fast_element_1.css `
            :host([appearance='lightweight'].disabled) .control {
              forced-color-adjust: none;
              color: ${fast_web_utilities_1.SystemColors.GrayText};
            }

            :host([appearance='lightweight'].disabled)
              .control:hover
              .content::before {
              background: none;
            }
          `))), appearanceBehavior('outline', fast_element_1.css `
        :host([appearance='outline'][disabled]),
        :host([appearance='outline'][disabled]:hover),
        :host([appearance='outline'][disabled]:active) {
          background: transparent;
          border-color: ${fast_components_1.accentFillRest};
        }

        ${OutlineButtonStyles}
      `.withBehaviors(fast_foundation_1.forcedColorsStylesheetBehavior(fast_element_1.css `
            :host([appearance='outline'][disabled]) .control {
              border-color: ${fast_web_utilities_1.SystemColors.GrayText};
            }
          `))), appearanceBehavior('stealth', fast_element_1.css `
        :host([appearance='stealth'][disabled]),
        :host([appearance='stealth'][disabled]:hover),
        :host([appearance='stealth'][disabled]:active) {
          background: ${fast_components_1.neutralFillStealthRest};
        }

        ${StealthButtonStyles}
      `.withBehaviors(fast_foundation_1.forcedColorsStylesheetBehavior(fast_element_1.css `
            :host([appearance='stealth'][disabled]) {
              background: ${fast_web_utilities_1.SystemColors.ButtonFace};
            }

            :host([appearance='stealth'][disabled]) .control {
              background: ${fast_web_utilities_1.SystemColors.ButtonFace};
              border-color: transparent;
              color: ${fast_web_utilities_1.SystemColors.GrayText};
            }
          `))));
exports.buttonStyles = buttonStyles;
//# sourceMappingURL=button.styles.js.map