"use strict";
// Copyright (c) Jupyter Development Team.
// Copyright (c) Microsoft Corporation.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkboxStyles = void 0;
const fast_components_1 = require("@microsoft/fast-components");
const fast_element_1 = require("@microsoft/fast-element");
const fast_foundation_1 = require("@microsoft/fast-foundation");
const fast_web_utilities_1 = require("@microsoft/fast-web-utilities");
const index_1 = require("../styles/index");
/**
 * Styles for Checkbox
 * @public
 */
const checkboxStyles = (context, definition) => fast_element_1.css `
    ${fast_foundation_1.display('inline-flex')} :host {
      align-items: center;
      outline: none;
      margin: calc(${fast_components_1.designUnit} * 1px) 0;
      /* Chromium likes to select label text or the default slot when the checkbox is
            clicked. Maybe there is a better solution here? */
      user-select: none;
    }

    .control {
      position: relative;
      width: calc((${index_1.heightNumber} / 2 + ${fast_components_1.designUnit}) * 1px);
      height: calc((${index_1.heightNumber} / 2 + ${fast_components_1.designUnit}) * 1px);
      box-sizing: border-box;
      border-radius: calc(${fast_components_1.controlCornerRadius} * 1px);
      border: calc(${fast_components_1.strokeWidth} * 1px) solid ${fast_components_1.neutralStrokeRest};
      background: ${fast_components_1.neutralFillInputRest};
      outline: none;
      cursor: pointer;
    }

    .label {
      font-family: ${fast_components_1.bodyFont};
      color: ${fast_components_1.neutralForegroundRest};
      /* Need to discuss with Brian how HorizontalSpacingNumber can work.
            https://github.com/microsoft/fast/issues/2766 */
      padding-inline-start: calc(${fast_components_1.designUnit} * 2px + 2px);
      margin-inline-end: calc(${fast_components_1.designUnit} * 2px + 2px);
      cursor: pointer;
      font-size: ${fast_components_1.typeRampBaseFontSize};
      line-height: ${fast_components_1.typeRampBaseLineHeight};
    }

    .label__hidden {
      display: none;
      visibility: hidden;
    }

    .checked-indicator {
      width: 100%;
      height: 100%;
      display: block;
      fill: ${fast_components_1.foregroundOnAccentRest};
      opacity: 0;
      pointer-events: none;
    }

    .indeterminate-indicator {
      border-radius: calc(${fast_components_1.controlCornerRadius} * 1px);
      background: ${fast_components_1.foregroundOnAccentRest};
      position: absolute;
      top: 50%;
      left: 50%;
      width: 50%;
      height: 50%;
      transform: translate(-50%, -50%);
      opacity: 0;
    }

    :host(:not([disabled])) .control:hover {
      background: ${fast_components_1.neutralFillInputHover};
      border-color: ${fast_components_1.neutralStrokeHover};
    }

    :host(:not([disabled])) .control:active {
      background: ${fast_components_1.neutralFillInputActive};
      border-color: ${fast_components_1.neutralStrokeActive};
    }

    :host(:${fast_foundation_1.focusVisible}) .control {
      outline: calc(${fast_components_1.focusStrokeWidth} * 1px) solid ${fast_components_1.accentFillFocus};
      outline-offset: 2px;
    }

    :host([aria-checked='true']) .control {
      background: ${fast_components_1.accentFillRest};
      border: calc(${fast_components_1.strokeWidth} * 1px) solid ${fast_components_1.accentFillRest};
    }

    :host([aria-checked='true']:not([disabled])) .control:hover {
      background: ${fast_components_1.accentFillHover};
      border: calc(${fast_components_1.strokeWidth} * 1px) solid ${fast_components_1.accentFillHover};
    }

    :host([aria-checked='true']:not([disabled]))
      .control:hover
      .checked-indicator {
      fill: ${fast_components_1.foregroundOnAccentHover};
    }

    :host([aria-checked='true']:not([disabled]))
      .control:hover
      .indeterminate-indicator {
      background: ${fast_components_1.foregroundOnAccentHover};
    }

    :host([aria-checked='true']:not([disabled])) .control:active {
      background: ${fast_components_1.accentFillActive};
      border: calc(${fast_components_1.strokeWidth} * 1px) solid ${fast_components_1.accentFillActive};
    }

    :host([aria-checked='true']:not([disabled]))
      .control:active
      .checked-indicator {
      fill: ${fast_components_1.foregroundOnAccentActive};
    }

    :host([aria-checked='true']:not([disabled]))
      .control:active
      .indeterminate-indicator {
      background: ${fast_components_1.foregroundOnAccentActive};
    }

    :host([aria-checked="true"]:${fast_foundation_1.focusVisible}:not([disabled])) .control {
      outline: calc(${fast_components_1.focusStrokeWidth} * 1px) solid ${fast_components_1.accentFillFocus};
      outline-offset: 2px;
    }

    :host([disabled]) .label,
    :host([readonly]) .label,
    :host([readonly]) .control,
    :host([disabled]) .control {
      cursor: ${fast_foundation_1.disabledCursor};
    }

    :host([aria-checked='true']:not(.indeterminate)) .checked-indicator,
    :host(.indeterminate) .indeterminate-indicator {
      opacity: 1;
    }

    :host([disabled]) {
      opacity: ${fast_components_1.disabledOpacity};
    }
  `.withBehaviors(fast_foundation_1.forcedColorsStylesheetBehavior(fast_element_1.css `
        .control {
          forced-color-adjust: none;
          border-color: ${fast_web_utilities_1.SystemColors.FieldText};
          background: ${fast_web_utilities_1.SystemColors.Field};
        }
        .checked-indicator {
          fill: ${fast_web_utilities_1.SystemColors.FieldText};
        }
        .indeterminate-indicator {
          background: ${fast_web_utilities_1.SystemColors.FieldText};
        }
        :host(:not([disabled])) .control:hover,
        .control:active {
          border-color: ${fast_web_utilities_1.SystemColors.Highlight};
          background: ${fast_web_utilities_1.SystemColors.Field};
        }
        :host(:${fast_foundation_1.focusVisible}) .control {
          outline: calc(${fast_components_1.focusStrokeWidth} * 1px) solid
            ${fast_web_utilities_1.SystemColors.FieldText};
          outline-offset: 2px;
        }
        :host([aria-checked="true"]:${fast_foundation_1.focusVisible}:not([disabled])) .control {
          outline: calc(${fast_components_1.focusStrokeWidth} * 1px) solid
            ${fast_web_utilities_1.SystemColors.FieldText};
          outline-offset: 2px;
        }
        :host([aria-checked='true']) .control {
          background: ${fast_web_utilities_1.SystemColors.Highlight};
          border-color: ${fast_web_utilities_1.SystemColors.Highlight};
        }
        :host([aria-checked='true']:not([disabled])) .control:hover,
        .control:active {
          border-color: ${fast_web_utilities_1.SystemColors.Highlight};
          background: ${fast_web_utilities_1.SystemColors.HighlightText};
        }
        :host([aria-checked='true']) .checked-indicator {
          fill: ${fast_web_utilities_1.SystemColors.HighlightText};
        }
        :host([aria-checked='true']:not([disabled]))
          .control:hover
          .checked-indicator {
          fill: ${fast_web_utilities_1.SystemColors.Highlight};
        }
        :host([aria-checked='true']) .indeterminate-indicator {
          background: ${fast_web_utilities_1.SystemColors.HighlightText};
        }
        :host([aria-checked='true']) .control:hover .indeterminate-indicator {
          background: ${fast_web_utilities_1.SystemColors.Highlight};
        }
        :host([disabled]) {
          opacity: 1;
        }
        :host([disabled]) .control {
          forced-color-adjust: none;
          border-color: ${fast_web_utilities_1.SystemColors.GrayText};
          background: ${fast_web_utilities_1.SystemColors.Field};
        }
        :host([disabled]) .indeterminate-indicator,
        :host([aria-checked='true'][disabled])
          .control:hover
          .indeterminate-indicator {
          forced-color-adjust: none;
          background: ${fast_web_utilities_1.SystemColors.GrayText};
        }
        :host([disabled]) .checked-indicator,
        :host([aria-checked='true'][disabled])
          .control:hover
          .checked-indicator {
          forced-color-adjust: none;
          fill: ${fast_web_utilities_1.SystemColors.GrayText};
        }
      `));
exports.checkboxStyles = checkboxStyles;
//# sourceMappingURL=checkbox.styles.js.map