"use strict";
// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.errorForegroundFocus = exports.errorForegroundActive = exports.errorForegroundHover = exports.errorForegroundRest = exports.errorForegroundRecipe = exports.foregroundOnErrorFocusLarge = exports.foregroundOnErrorActiveLarge = exports.foregroundOnErrorHoverLarge = exports.foregroundOnErrorRestLarge = exports.foregroundOnErrorLargeRecipe = exports.foregroundOnErrorFocus = exports.foregroundOnErrorActive = exports.foregroundOnErrorHover = exports.foregroundOnErrorRest = exports.foregroundOnErrorRecipe = exports.errorFillFocus = exports.errorFillActive = exports.errorFillHover = exports.errorFillRest = exports.errorFillRecipe = exports.errorPalette = void 0;
const fast_components_1 = require("@microsoft/fast-components");
const fast_foundation_1 = require("@microsoft/fast-foundation");
const colors_1 = require("./colors");
const { create } = fast_foundation_1.DesignToken;
/*
 * The error palette is built using the same color algorithm as the accent palette
 * But by copying the algorithm from @microsoft/fast-components at commit 03d711f222bd816834a5e1d60256d3e083b27c27
 * as some helpers are not exported.
 * The delta used are those of the accent palette.
 */
/**
 * Error palette
 */
exports.errorPalette = create({
    name: 'error-palette',
    cssCustomPropertyName: null
}).withDefault(fast_components_1.PaletteRGB.from(colors_1.errorBase));
// Error Fill
/** @public */
exports.errorFillRecipe = create({
    name: 'error-fill-recipe',
    cssCustomPropertyName: null
}).withDefault({
    evaluate: (element, reference) => colors_1.errorFillAlgorithm(exports.errorPalette.getValueFor(element), fast_components_1.neutralPalette.getValueFor(element), reference || fast_components_1.fillColor.getValueFor(element), fast_components_1.accentFillHoverDelta.getValueFor(element), fast_components_1.accentFillActiveDelta.getValueFor(element), fast_components_1.accentFillFocusDelta.getValueFor(element), fast_components_1.neutralFillRestDelta.getValueFor(element), fast_components_1.neutralFillHoverDelta.getValueFor(element), fast_components_1.neutralFillActiveDelta.getValueFor(element))
});
/** @public */
exports.errorFillRest = create('error-fill-rest').withDefault((element) => {
    return exports.errorFillRecipe.getValueFor(element).evaluate(element).rest;
});
/** @public */
exports.errorFillHover = create('error-fill-hover').withDefault((element) => {
    return exports.errorFillRecipe.getValueFor(element).evaluate(element).hover;
});
/** @public */
exports.errorFillActive = create('error-fill-active').withDefault((element) => {
    return exports.errorFillRecipe.getValueFor(element).evaluate(element).active;
});
/** @public */
exports.errorFillFocus = create('error-fill-focus').withDefault((element) => {
    return exports.errorFillRecipe.getValueFor(element).evaluate(element).focus;
});
// Foreground On Error
const foregroundOnErrorByContrast = (contrast) => (element, reference) => {
    return colors_1.foregroundOnErrorAlgorithm(reference || exports.errorFillRest.getValueFor(element), contrast);
};
/** @public */
exports.foregroundOnErrorRecipe = create({
    name: 'foreground-on-error-recipe',
    cssCustomPropertyName: null
}).withDefault({
    evaluate: (element, reference) => foregroundOnErrorByContrast(colors_1.ContrastTarget.normal)(element, reference)
});
/** @public */
exports.foregroundOnErrorRest = create('foreground-on-error-rest').withDefault((element) => exports.foregroundOnErrorRecipe
    .getValueFor(element)
    .evaluate(element, exports.errorFillRest.getValueFor(element)));
/** @public */
exports.foregroundOnErrorHover = create('foreground-on-error-hover').withDefault((element) => exports.foregroundOnErrorRecipe
    .getValueFor(element)
    .evaluate(element, exports.errorFillHover.getValueFor(element)));
/** @public */
exports.foregroundOnErrorActive = create('foreground-on-error-active').withDefault((element) => exports.foregroundOnErrorRecipe
    .getValueFor(element)
    .evaluate(element, exports.errorFillActive.getValueFor(element)));
/** @public */
exports.foregroundOnErrorFocus = create('foreground-on-error-focus').withDefault((element) => exports.foregroundOnErrorRecipe
    .getValueFor(element)
    .evaluate(element, exports.errorFillFocus.getValueFor(element)));
/** @public */
exports.foregroundOnErrorLargeRecipe = create({
    name: 'foreground-on-error-large-recipe',
    cssCustomPropertyName: null
}).withDefault({
    evaluate: (element, reference) => foregroundOnErrorByContrast(colors_1.ContrastTarget.large)(element, reference)
});
/** @public */
exports.foregroundOnErrorRestLarge = create('foreground-on-error-rest-large').withDefault((element) => exports.foregroundOnErrorLargeRecipe
    .getValueFor(element)
    .evaluate(element, exports.errorFillRest.getValueFor(element)));
/** @public */
exports.foregroundOnErrorHoverLarge = create('foreground-on-error-hover-large').withDefault((element) => exports.foregroundOnErrorLargeRecipe
    .getValueFor(element)
    .evaluate(element, exports.errorFillHover.getValueFor(element)));
/** @public */
exports.foregroundOnErrorActiveLarge = create('foreground-on-error-active-large').withDefault((element) => exports.foregroundOnErrorLargeRecipe
    .getValueFor(element)
    .evaluate(element, exports.errorFillActive.getValueFor(element)));
/** @public */
exports.foregroundOnErrorFocusLarge = create('foreground-on-error-focus-large').withDefault((element) => exports.foregroundOnErrorLargeRecipe
    .getValueFor(element)
    .evaluate(element, exports.errorFillFocus.getValueFor(element)));
// Error Foreground
const errorForegroundByContrast = (contrast) => (element, reference) => colors_1.errorForegroundAlgorithm(exports.errorPalette.getValueFor(element), reference || fast_components_1.fillColor.getValueFor(element), contrast, fast_components_1.accentForegroundRestDelta.getValueFor(element), fast_components_1.accentForegroundHoverDelta.getValueFor(element), fast_components_1.accentForegroundActiveDelta.getValueFor(element), fast_components_1.accentForegroundFocusDelta.getValueFor(element));
/** @public */
exports.errorForegroundRecipe = create({
    name: 'error-foreground-recipe',
    cssCustomPropertyName: null
}).withDefault({
    evaluate: (element, reference) => errorForegroundByContrast(colors_1.ContrastTarget.normal)(element, reference)
});
/** @public */
exports.errorForegroundRest = create('error-foreground-rest').withDefault((element) => exports.errorForegroundRecipe.getValueFor(element).evaluate(element).rest);
/** @public */
exports.errorForegroundHover = create('error-foreground-hover').withDefault((element) => exports.errorForegroundRecipe.getValueFor(element).evaluate(element).hover);
/** @public */
exports.errorForegroundActive = create('error-foreground-active').withDefault((element) => exports.errorForegroundRecipe.getValueFor(element).evaluate(element).active);
/** @public */
exports.errorForegroundFocus = create('error-foreground-focus').withDefault((element) => exports.errorForegroundRecipe.getValueFor(element).evaluate(element).focus);
//# sourceMappingURL=design-token.js.map