"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sliderStyles = void 0;
const fast_element_1 = require("@microsoft/fast-element");
const fast_foundation_1 = require("@microsoft/fast-foundation");
const fast_web_utilities_1 = require("@microsoft/fast-web-utilities");
const fast_components_1 = require("@microsoft/fast-components");
const index_1 = require("../styles/index");
/**
 * Styles for Slider
 * @public
 */
const sliderStyles = (context, definition) => fast_element_1.css `
    :host([hidden]) {
      display: none;
    }

    ${fast_foundation_1.display('inline-grid')} :host {
      --thumb-size: calc(${index_1.heightNumber} * 0.5 - ${fast_components_1.designUnit});
      --thumb-translate: calc(
        var(--thumb-size) * -0.5 + var(--track-width) / 2
      );
      --track-overhang: calc((${fast_components_1.designUnit} / 2) * -1);
      --track-width: ${fast_components_1.designUnit};
      --jp-slider-height: calc(var(--thumb-size) * 10);
      align-items: center;
      width: 100%;
      margin: calc(${fast_components_1.designUnit} * 1px) 0;
      user-select: none;
      box-sizing: border-box;
      border-radius: calc(${fast_components_1.controlCornerRadius} * 1px);
      outline: none;
      cursor: pointer;
    }
    :host([orientation='horizontal']) .positioning-region {
      position: relative;
      margin: 0 8px;
      display: grid;
      grid-template-rows: calc(var(--thumb-size) * 1px) 1fr;
    }
    :host([orientation='vertical']) .positioning-region {
      position: relative;
      margin: 0 8px;
      display: grid;
      height: 100%;
      grid-template-columns: calc(var(--thumb-size) * 1px) 1fr;
    }

    :host(:${fast_foundation_1.focusVisible}) .thumb-cursor {
      box-shadow: 0 0 0 2px ${fast_components_1.fillColor},
        0 0 0 calc((2 + ${fast_components_1.focusStrokeWidth}) * 1px) ${fast_components_1.accentFillFocus};
    }

    .thumb-container {
      position: absolute;
      height: calc(var(--thumb-size) * 1px);
      width: calc(var(--thumb-size) * 1px);
      transition: all 0.2s ease;
      color: ${fast_components_1.neutralForegroundRest};
      fill: currentcolor;
    }
    .thumb-cursor {
      border: none;
      width: calc(var(--thumb-size) * 1px);
      height: calc(var(--thumb-size) * 1px);
      background: ${fast_components_1.neutralForegroundRest};
      border-radius: calc(${fast_components_1.controlCornerRadius} * 1px);
    }
    .thumb-cursor:hover {
      background: ${fast_components_1.neutralForegroundRest};
      border-color: ${fast_components_1.neutralStrokeHover};
    }
    .thumb-cursor:active {
      background: ${fast_components_1.neutralForegroundRest};
    }
    :host([orientation='horizontal']) .thumb-container {
      transform: translateX(calc(var(--thumb-size) * 0.5px))
        translateY(calc(var(--thumb-translate) * 1px));
    }
    :host([orientation='vertical']) .thumb-container {
      transform: translateX(calc(var(--thumb-translate) * 1px))
        translateY(calc(var(--thumb-size) * 0.5px));
    }
    :host([orientation='horizontal']) {
      min-width: calc(var(--thumb-size) * 1px);
    }
    :host([orientation='horizontal']) .track {
      right: calc(var(--track-overhang) * 1px);
      left: calc(var(--track-overhang) * 1px);
      align-self: start;
      height: calc(var(--track-width) * 1px);
    }
    :host([orientation='vertical']) .track {
      top: calc(var(--track-overhang) * 1px);
      bottom: calc(var(--track-overhang) * 1px);
      width: calc(var(--track-width) * 1px);
      height: 100%;
    }
    .track {
      background: ${fast_components_1.neutralStrokeRest};
      position: absolute;
      border-radius: calc(${fast_components_1.controlCornerRadius} * 1px);
    }
    :host([orientation='vertical']) {
      height: calc(var(--jp-slider-height) * 1px);
      min-height: calc(var(--thumb-size) * 1px);
      min-width: calc(${fast_components_1.designUnit} * 20px);
    }
    :host([disabled]),
    :host([readonly]) {
      cursor: ${fast_foundation_1.disabledCursor};
    }
    :host([disabled]) {
      opacity: ${fast_components_1.disabledOpacity};
    }
  `.withBehaviors(fast_foundation_1.forcedColorsStylesheetBehavior(fast_element_1.css `
        .thumb-cursor {
          forced-color-adjust: none;
          border-color: ${fast_web_utilities_1.SystemColors.FieldText};
          background: ${fast_web_utilities_1.SystemColors.FieldText};
        }
        .thumb-cursor:hover,
        .thumb-cursor:active {
          background: ${fast_web_utilities_1.SystemColors.Highlight};
        }
        .track {
          forced-color-adjust: none;
          background: ${fast_web_utilities_1.SystemColors.FieldText};
        }
        :host(:${fast_foundation_1.focusVisible}) .thumb-cursor {
          border-color: ${fast_web_utilities_1.SystemColors.Highlight};
        }
        :host([disabled]) {
          opacity: 1;
        }
        :host([disabled]) .track,
        :host([disabled]) .thumb-cursor {
          forced-color-adjust: none;
          background: ${fast_web_utilities_1.SystemColors.GrayText};
        }

        :host(:${fast_foundation_1.focusVisible}) .thumb-cursor {
          background: ${fast_web_utilities_1.SystemColors.Highlight};
          border-color: ${fast_web_utilities_1.SystemColors.Highlight};
          box-shadow: 0 0 0 2px ${fast_web_utilities_1.SystemColors.Field},
            0 0 0 4px ${fast_web_utilities_1.SystemColors.FieldText};
        }
      `));
exports.sliderStyles = sliderStyles;
//# sourceMappingURL=slider.styles.js.map