"use strict";
// Copyright (c) Jupyter Development Team.
// Copyright (c) Microsoft Corporation.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseFieldStyles = void 0;
const fast_components_1 = require("@microsoft/fast-components");
const fast_element_1 = require("@microsoft/fast-element");
const fast_foundation_1 = require("@microsoft/fast-foundation");
const fast_web_utilities_1 = require("@microsoft/fast-web-utilities");
const size_1 = require("../size");
exports.BaseFieldStyles = fast_element_1.css `
  ${fast_foundation_1.display('inline-block')} :host {
    font-family: ${fast_components_1.bodyFont};
    outline: none;
    user-select: none;
  }

  .root {
    box-sizing: border-box;
    position: relative;
    display: flex;
    flex-direction: row;
    color: ${fast_components_1.neutralForegroundRest};
    background: ${fast_components_1.neutralFillInputRest};
    border-radius: calc(${fast_components_1.controlCornerRadius} * 1px);
    border: calc(${fast_components_1.strokeWidth} * 1px) solid ${fast_components_1.neutralFillStrongRest};
    height: calc(${size_1.heightNumber} * 1px);
  }

  .control {
    -webkit-appearance: none;
    font: inherit;
    background: transparent;
    border: 0;
    color: inherit;
    height: calc(100% - 4px);
    width: 100%;
    margin-top: auto;
    margin-bottom: auto;
    border: none;
    padding: 0 calc(${fast_components_1.designUnit} * 2px + 1px);
    font-size: ${fast_components_1.typeRampBaseFontSize};
    line-height: ${fast_components_1.typeRampBaseLineHeight};
  }

  .control:hover,
  .control:${fast_foundation_1.focusVisible},
  .control:disabled,
  .control:active {
    outline: none;
  }

  .label {
    display: block;
    color: ${fast_components_1.neutralForegroundRest};
    cursor: pointer;
    font-size: ${fast_components_1.typeRampBaseFontSize};
    line-height: ${fast_components_1.typeRampBaseLineHeight};
    margin-bottom: 4px;
  }

  .label__hidden {
    display: none;
    visibility: hidden;
  }

  .start,
  .end {
    margin: auto;
    fill: currentcolor;
  }

  ::slotted(svg) {
    /* TODO: adaptive typography https://github.com/microsoft/fast/issues/2432 */
    width: 16px;
    height: 16px;
  }

  .start {
    margin-inline-start: 11px;
  }

  .end {
    margin-inline-end: 11px;
  }

  :host(:hover:not([disabled])) .root {
    background: ${fast_components_1.neutralFillInputHover};
    border-color: ${fast_components_1.neutralFillStrongHover};
  }

  :host(:active:not([disabled])) .root {
    background: ${fast_components_1.neutralFillInputHover};
    border-color: ${fast_components_1.neutralFillStrongActive};
  }

  :host(:focus-within:not([disabled])) .root {
    border-color: ${fast_components_1.accentFillFocus};
    box-shadow: 0 0 0 calc((${fast_components_1.focusStrokeWidth} - ${fast_components_1.strokeWidth}) * 1px)
      ${fast_components_1.accentFillFocus};
  }

  :host([appearance='filled']) .root {
    background: ${fast_components_1.neutralFillRest};
  }

  :host([appearance='filled']:hover:not([disabled])) .root {
    background: ${fast_components_1.neutralFillHover};
  }

  :host([disabled]) .label,
  :host([readonly]) .label,
  :host([readonly]) .control,
  :host([disabled]) .control {
    cursor: ${fast_foundation_1.disabledCursor};
  }

  :host([disabled]) {
    opacity: ${fast_components_1.disabledOpacity};
  }

  :host([disabled]) .control {
    border-color: ${fast_components_1.neutralStrokeRest};
  }
`.withBehaviors(fast_foundation_1.forcedColorsStylesheetBehavior(fast_element_1.css `
      .root,
      :host([appearance='filled']) .root {
        forced-color-adjust: none;
        background: ${fast_web_utilities_1.SystemColors.Field};
        border-color: ${fast_web_utilities_1.SystemColors.FieldText};
      }
      :host(:hover:not([disabled])) .root,
      :host([appearance='filled']:hover:not([disabled])) .root,
      :host([appearance='filled']:hover) .root {
        background: ${fast_web_utilities_1.SystemColors.Field};
        border-color: ${fast_web_utilities_1.SystemColors.Highlight};
      }
      .start,
      .end {
        fill: currentcolor;
      }
      :host([disabled]) {
        opacity: 1;
      }
      :host([disabled]) .root,
      :host([appearance='filled']:hover[disabled]) .root {
        border-color: ${fast_web_utilities_1.SystemColors.GrayText};
        background: ${fast_web_utilities_1.SystemColors.Field};
      }
      :host(:focus-within:enabled) .root {
        border-color: ${fast_web_utilities_1.SystemColors.Highlight};
        box-shadow: 0 0 0 calc((${fast_components_1.focusStrokeWidth} - ${fast_components_1.strokeWidth}) * 1px)
          ${fast_web_utilities_1.SystemColors.Highlight};
      }
      input::placeholder {
        color: ${fast_web_utilities_1.SystemColors.GrayText};
      }
    `));
//# sourceMappingURL=field.js.map