"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.tabsStyles = void 0;
const fast_element_1 = require("@microsoft/fast-element");
const fast_foundation_1 = require("@microsoft/fast-foundation");
const fast_web_utilities_1 = require("@microsoft/fast-web-utilities");
const fast_components_1 = require("@microsoft/fast-components");
const index_1 = require("../styles/index");
/**
 * Styles for Tabs
 * @public
 */
const tabsStyles = (context, definition) => fast_element_1.css `
    ${fast_foundation_1.display('grid')} :host {
      box-sizing: border-box;
      font-family: ${fast_components_1.bodyFont};
      font-size: ${fast_components_1.typeRampBaseFontSize};
      line-height: ${fast_components_1.typeRampBaseLineHeight};
      color: ${fast_components_1.neutralForegroundRest};
      grid-template-columns: auto 1fr auto;
      grid-template-rows: auto 1fr;
    }

    .tablist {
      display: grid;
      grid-template-rows: auto auto;
      grid-template-columns: auto;
      position: relative;
      width: max-content;
      align-self: end;
      padding: calc(${fast_components_1.designUnit} * 4px) calc(${fast_components_1.designUnit} * 4px) 0;
      box-sizing: border-box;
    }

    .start,
    .end {
      align-self: center;
    }

    .activeIndicator {
      grid-row: 1;
      grid-column: 1;
      width: 100%;
      height: 4px;
      justify-self: center;
      background: ${fast_components_1.accentFillRest};
      margin-top: 0;
      border-radius: calc(${fast_components_1.controlCornerRadius} * 1px)
        calc(${fast_components_1.controlCornerRadius} * 1px) 0 0;
    }

    .activeIndicatorTransition {
      transition: transform 0.01s ease-in-out;
    }

    .tabpanel {
      grid-row: 2;
      grid-column-start: 1;
      grid-column-end: 4;
      position: relative;
    }

    :host([orientation='vertical']) {
      grid-template-rows: auto 1fr auto;
      grid-template-columns: auto 1fr;
    }

    :host([orientation='vertical']) .tablist {
      grid-row-start: 2;
      grid-row-end: 2;
      display: grid;
      grid-template-rows: auto;
      grid-template-columns: auto 1fr;
      position: relative;
      width: max-content;
      justify-self: end;
      align-self: flex-start;
      width: 100%;
      padding: 0 calc(${fast_components_1.designUnit} * 4px)
        calc((${index_1.heightNumber} - ${fast_components_1.designUnit}) * 1px) 0;
    }

    :host([orientation='vertical']) .tabpanel {
      grid-column: 2;
      grid-row-start: 1;
      grid-row-end: 4;
    }

    :host([orientation='vertical']) .end {
      grid-row: 3;
    }

    :host([orientation='vertical']) .activeIndicator {
      grid-column: 1;
      grid-row: 1;
      width: 4px;
      height: 100%;
      margin-inline-end: 0px;
      align-self: center;
      border-radius: calc(${fast_components_1.controlCornerRadius} * 1px) 0 0
        calc(${fast_components_1.controlCornerRadius} * 1px);
    }

    :host([orientation='vertical']) .activeIndicatorTransition {
      transition: transform 0.01s ease-in-out;
    }
  `.withBehaviors(fast_foundation_1.forcedColorsStylesheetBehavior(fast_element_1.css `
        .activeIndicator,
        :host([orientation='vertical']) .activeIndicator {
          forced-color-adjust: none;
          background: ${fast_web_utilities_1.SystemColors.Highlight};
        }
      `));
exports.tabsStyles = tabsStyles;
//# sourceMappingURL=tabs.styles.js.map